weeWX: Installation using yum

# yum repository for weeWX

## Tell the system to trust weewx.com

    sudo rpm --import http://weewx.com/keys.html

## Configure yum

For python3 (redhat 8):

    curl -s http://weewx.com/yum/weewx-el8.repo | sudo tee /etc/yum.repos.d/weewx.repo

For python2 (redhat 7):

    curl -s http://weewx.com/yum/weewx-el7.repo | sudo tee /etc/yum.repos.d/weewx.repo

## Install weeWX

    sudo yum install weewx

## Update weeWX

    sudo yum update weewx